@@ -1,10 +1,10 @@
-/* $Id: time.cpp 96257 2014-09-24 14:48:48Z fmehnert $ */
+/* $Id: time.cpp 100874 2015-06-09 14:01:31Z bird $ */
 /** @file
  * IPRT - Time.
  */
 
 /*
- * Copyright (C) 2006-2012 Oracle Corporation
+ * Copyright (C) 2006-2015 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -800,7 +800,7 @@ RTDECL(PRTTIME) RTTimeFromString(PRTTIME pTime, const char *pszString)
         return NULL;
     unsigned const cDaysInMonth = fLeapYear
                                 ? g_acDaysInMonthsLeap[pTime->u8Month - 1]
-                                : g_acDaysInMonthsLeap[pTime->u8Month - 1];
+                                : g_acDaysInMonths[pTime->u8Month - 1];
     if (pTime->u8MonthDay == 0 || pTime->u8MonthDay > cDaysInMonth)
         return NULL;
 
