@@ -1,10 +1,10 @@
-/* $Id: VBoxNetAdp-linux.c 102794 2015-09-21 15:41:19Z fmehnert $ */
+/* $Id: VBoxNetAdp-linux.c 100877 2015-06-09 14:23:56Z bird $ */
 /** @file
  * VBoxNetAdp - Virtual Network Adapter Driver (Host), Linux Specific Code.
  */
 
 /*
- * Copyright (C) 2009-2012 Oracle Corporation
+ * Copyright (C) 2009-2015 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -423,6 +423,7 @@ static int __init VBoxNetAdpLinuxInit(void)
  */
 static void __exit VBoxNetAdpLinuxUnload(void)
 {
+    int rc;
     Log(("VBoxNetAdpLinuxUnload\n"));
 
     /*
@@ -431,7 +432,11 @@ static void __exit VBoxNetAdpLinuxUnload(void)
 
     vboxNetAdpShutdown();
     /* Remove control device */
-    misc_deregister(&g_CtlDev);
+    rc = misc_deregister(&g_CtlDev);
+    if (rc < 0)
+    {
+        printk(KERN_ERR "misc_deregister failed with rc=%x\n", rc);
+    }
 
     RTR0Term();
 
