@@ -1,10 +1,10 @@
-/* $Id: initterm-r0drv-linux.c 103354 2015-10-13 14:24:51Z bird $ */
+/* $Id: initterm-r0drv-linux.c 100874 2015-06-09 14:01:31Z bird $ */
 /** @file
  * IPRT - Initialization & Termination, R0 Driver, Linux.
  */
 
 /*
- * Copyright (C) 2006-2012 Oracle Corporation
+ * Copyright (C) 2006-2015 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -49,10 +49,8 @@ static DECLARE_TASK_QUEUE(g_rtR0LnxWorkQueue);
 /*******************************************************************************
 *   Internal Functions                                                         *
 *******************************************************************************/
-#if defined(RT_ARCH_AMD64) && LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 23)
 /* in alloc-r0drv0-linux.c */
 DECLHIDDEN(void) rtR0MemExecCleanup(void);
-#endif
 
 
 /**
@@ -64,8 +62,6 @@ DECLHIDDEN(void) rtR0MemExecCleanup(void);
  */
 DECLHIDDEN(void) rtR0LnxWorkqueuePush(RTR0LNXWORKQUEUEITEM *pWork, void (*pfnWorker)(RTR0LNXWORKQUEUEITEM *))
 {
-    IPRT_LINUX_SAVE_EFL_AC();
-
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 41)
 # if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 20)
     INIT_WORK(pWork, pfnWorker);
@@ -77,8 +73,6 @@ DECLHIDDEN(void) rtR0LnxWorkqueuePush(RTR0LNXWORKQUEUEITEM *pWork, void (*pfnWor
     INIT_TQUEUE(pWork, (void (*)(void *))pfnWorker, pWork);
     queue_task(pWork, &g_rtR0LnxWorkQueue);
 #endif
-
-    IPRT_LINUX_RESTORE_EFL_AC();
 }
 
 
@@ -90,48 +84,38 @@ DECLHIDDEN(void) rtR0LnxWorkqueuePush(RTR0LNXWORKQUEUEITEM *pWork, void (*pfnWor
  */
 DECLHIDDEN(void) rtR0LnxWorkqueueFlush(void)
 {
-    IPRT_LINUX_SAVE_EFL_AC();
-
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 41)
     flush_workqueue(g_prtR0LnxWorkQueue);
 #else
     run_task_queue(&g_rtR0LnxWorkQueue);
 #endif
-
-    IPRT_LINUX_RESTORE_EFL_AC();
 }
 
 
 DECLHIDDEN(int) rtR0InitNative(void)
 {
-    int rc = VINF_SUCCESS;
-    IPRT_LINUX_SAVE_EFL_AC();
-
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 41)
-    g_prtR0LnxWorkQueue = create_workqueue("iprt");
+ #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 13)
+    g_prtR0LnxWorkQueue = create_workqueue("iprt-VBoxWQueue");
+ #else
+    g_prtR0LnxWorkQueue = create_workqueue("iprt-VBoxQ");
+ #endif
     if (!g_prtR0LnxWorkQueue)
-        rc = VERR_NO_MEMORY;
+        return VERR_NO_MEMORY;
 #endif
 
-    IPRT_LINUX_RESTORE_EFL_AC();
-    return rc;
+    return VINF_SUCCESS;
 }
 
 
 DECLHIDDEN(void) rtR0TermNative(void)
 {
-    IPRT_LINUX_SAVE_EFL_AC();
-
     rtR0LnxWorkqueueFlush();
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 41)
     destroy_workqueue(g_prtR0LnxWorkQueue);
     g_prtR0LnxWorkQueue = NULL;
 #endif
 
-#if defined(RT_ARCH_AMD64) && LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 23)
     rtR0MemExecCleanup();
-#endif
-
-    IPRT_LINUX_RESTORE_EFL_AC();
 }
 
