@@ -1,10 +1,10 @@
-/* $Id: memuserkernel-r0drv-linux.c 103354 2015-10-13 14:24:51Z bird $ */
+/* $Id: memuserkernel-r0drv-linux.c 100874 2015-06-09 14:01:31Z bird $ */
 /** @file
  * IPRT - User & Kernel Memory, Ring-0 Driver, Linux.
  */
 
 /*
- * Copyright (C) 2009-2012 Oracle Corporation
+ * Copyright (C) 2009-2015 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -37,13 +37,8 @@
 
 RTR0DECL(int) RTR0MemUserCopyFrom(void *pvDst, RTR3PTR R3PtrSrc, size_t cb)
 {
-    IPRT_LINUX_SAVE_EFL_AC();
     if (RT_LIKELY(copy_from_user(pvDst, (void *)R3PtrSrc, cb) == 0))
-    {
-        IPRT_LINUX_RESTORE_EFL_AC();
         return VINF_SUCCESS;
-    }
-    IPRT_LINUX_RESTORE_EFL_AC();
     return VERR_ACCESS_DENIED;
 }
 RT_EXPORT_SYMBOL(RTR0MemUserCopyFrom);
@@ -51,13 +46,8 @@ RT_EXPORT_SYMBOL(RTR0MemUserCopyFrom);
 
 RTR0DECL(int) RTR0MemUserCopyTo(RTR3PTR R3PtrDst, void const *pvSrc, size_t cb)
 {
-    IPRT_LINUX_SAVE_EFL_AC();
     if (RT_LIKELY(copy_to_user((void *)R3PtrDst, pvSrc, cb) == 0))
-    {
-        IPRT_LINUX_RESTORE_EFL_AC();
         return VINF_SUCCESS;
-    }
-    IPRT_LINUX_RESTORE_EFL_AC();
     return VERR_ACCESS_DENIED;
 }
 RT_EXPORT_SYMBOL(RTR0MemUserCopyTo);
@@ -65,10 +55,7 @@ RT_EXPORT_SYMBOL(RTR0MemUserCopyTo);
 
 RTR0DECL(bool) RTR0MemUserIsValidAddr(RTR3PTR R3Ptr)
 {
-    IPRT_LINUX_SAVE_EFL_AC();
-    bool fRc = access_ok(VERIFY_READ, (void *)R3Ptr, 1);
-    IPRT_LINUX_RESTORE_EFL_AC();
-    return fRc;
+    return access_ok(VERIFY_READ, (void *)R3Ptr, 1);
 }
 RT_EXPORT_SYMBOL(RTR0MemUserIsValidAddr);
 
@@ -126,7 +113,6 @@ static int rtR0MemKernelCopyLnxWorker(void *pvDst, void const *pvSrc, size_t cb)
 #  endif
 # endif /* !_ASM_EXTABLE */
     int rc;
-    IPRT_LINUX_SAVE_EFL_AC(); /* paranoia */
     if (!cb)
         return VINF_SUCCESS;
 
@@ -149,7 +135,6 @@ static int rtR0MemKernelCopyLnxWorker(void *pvDst, void const *pvSrc, size_t cb)
                             "2" (pvSrc),
                             "3" (cb)
                           : "memory");
-    IPRT_LINUX_RESTORE_EFL_AC();
     return rc;
 #else
     return VERR_NOT_SUPPORTED;
