@@ -1,10 +1,10 @@
-/* $Id: semevent-r0drv-linux.c 103354 2015-10-13 14:24:51Z bird $ */
+/* $Id: semevent-r0drv-linux.c 100874 2015-06-09 14:01:31Z bird $ */
 /** @file
  * IPRT - Single Release Event Semaphores, Ring-0 Driver, Linux.
  */
 
 /*
- * Copyright (C) 2006-2011 Oracle Corporation
+ * Copyright (C) 2006-2015 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -72,7 +72,6 @@ RTDECL(int)  RTSemEventCreate(PRTSEMEVENT phEventSem)
 RTDECL(int)  RTSemEventCreateEx(PRTSEMEVENT phEventSem, uint32_t fFlags, RTLOCKVALCLASS hClass, const char *pszNameFmt, ...)
 {
     PRTSEMEVENTINTERNAL pThis;
-    IPRT_LINUX_SAVE_EFL_AC();
 
     AssertReturn(!(fFlags & ~(RTSEMEVENT_FLAGS_NO_LOCK_VAL | RTSEMEVENT_FLAGS_BOOTSTRAP_HACK)), VERR_INVALID_PARAMETER);
     Assert(!(fFlags & RTSEMEVENT_FLAGS_BOOTSTRAP_HACK) || (fFlags & RTSEMEVENT_FLAGS_NO_LOCK_VAL));
@@ -87,7 +86,6 @@ RTDECL(int)  RTSemEventCreateEx(PRTSEMEVENT phEventSem, uint32_t fFlags, RTLOCKV
     init_waitqueue_head(&pThis->Head);
 
     *phEventSem = pThis;
-    IPRT_LINUX_RESTORE_EFL_AC();
     return VINF_SUCCESS;
 }
 RT_EXPORT_SYMBOL(RTSemEventCreate);
@@ -119,8 +117,6 @@ DECLINLINE(void) rtR0SemEventLnxRelease(PRTSEMEVENTINTERNAL pThis)
 
 RTDECL(int)  RTSemEventDestroy(RTSEMEVENT hEventSem)
 {
-    IPRT_LINUX_SAVE_EFL_AC();
-
     /*
      * Validate input.
      */
@@ -138,8 +134,6 @@ RTDECL(int)  RTSemEventDestroy(RTSEMEVENT hEventSem)
     Assert(!waitqueue_active(&pThis->Head));
     wake_up_all(&pThis->Head);
     rtR0SemEventLnxRelease(pThis);
-
-    IPRT_LINUX_RESTORE_EFL_AC();
     return VINF_SUCCESS;
 }
 RT_EXPORT_SYMBOL(RTSemEventDestroy);
@@ -147,8 +141,6 @@ RT_EXPORT_SYMBOL(RTSemEventDestroy);
 
 RTDECL(int)  RTSemEventSignal(RTSEMEVENT hEventSem)
 {
-    IPRT_LINUX_SAVE_EFL_AC();
-
     /*
      * Validate input.
      */
@@ -164,7 +156,6 @@ RTDECL(int)  RTSemEventSignal(RTSEMEVENT hEventSem)
     wake_up(&pThis->Head);
 
     rtR0SemEventLnxRelease(pThis);
-    IPRT_LINUX_RESTORE_EFL_AC();
     return VINF_SUCCESS;
 }
 RT_EXPORT_SYMBOL(RTSemEventSignal);
@@ -203,7 +194,6 @@ static int rtR0SemEventLnxWait(PRTSEMEVENTINTERNAL pThis, uint32_t fFlags, uint6
         /*
          * We have to wait.
          */
-        IPRT_LINUX_SAVE_EFL_AC();
         RTR0SEMLNXWAIT Wait;
         rc = rtR0SemLnxWaitInit(&Wait, fFlags, uTimeout, &pThis->Head);
         if (RT_SUCCESS(rc))
@@ -240,7 +230,6 @@ static int rtR0SemEventLnxWait(PRTSEMEVENTINTERNAL pThis, uint32_t fFlags, uint6
             rtR0SemLnxWaitDelete(&Wait);
             IPRT_DEBUG_SEMS_STATE_RC(pThis, 'E', rc);
         }
-        IPRT_LINUX_RESTORE_EFL_AC();
     }
 
     rtR0SemEventLnxRelease(pThis);
