@@ -1,10 +1,10 @@
-/* $Id: semmutex-r0drv-linux.c 103354 2015-10-13 14:24:51Z bird $ */
+/* $Id: semmutex-r0drv-linux.c 100874 2015-06-09 14:01:31Z bird $ */
 /** @file
  * IPRT - Mutex Semaphores, Ring-0 Driver, Linux.
  */
 
 /*
- * Copyright (C) 2006-2011 Oracle Corporation
+ * Copyright (C) 2006-2015 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -86,33 +86,26 @@ typedef struct RTSEMMUTEXINTERNAL
 
 RTDECL(int) RTSemMutexCreate(PRTSEMMUTEX phMtx)
 {
-    int rc = VINF_SUCCESS;
-    IPRT_LINUX_SAVE_EFL_AC();
-
     /*
      * Allocate.
      */
     PRTSEMMUTEXINTERNAL pThis;
     pThis = (PRTSEMMUTEXINTERNAL)RTMemAlloc(sizeof(*pThis));
-    if (pThis)
-    {
-        /*
-         * Initialize.
-         */
-        pThis->u32Magic     = RTSEMMUTEX_MAGIC;
-        pThis->cRecursions  = 0;
-        pThis->pOwnerTask   = NULL;
-        pThis->cRefs        = 1;
-        RTListInit(&pThis->WaiterList);
-        spin_lock_init(&pThis->Spinlock);
+    if (!pThis)
+        return VERR_NO_MEMORY;
 
-        *phMtx = pThis;
-    }
-    else
-        rc = VERR_NO_MEMORY;
+    /*
+     * Initialize.
+     */
+    pThis->u32Magic     = RTSEMMUTEX_MAGIC;
+    pThis->cRecursions  = 0;
+    pThis->pOwnerTask   = NULL;
+    pThis->cRefs        = 1;
+    RTListInit(&pThis->WaiterList);
+    spin_lock_init(&pThis->Spinlock);
 
-    IPRT_LINUX_RESTORE_EFL_AC();
-    return rc;
+    *phMtx = pThis;
+    return VINF_SUCCESS;
 }
 RT_EXPORT_SYMBOL(RTSemMutexCreate);
 
@@ -136,8 +129,6 @@ RTDECL(int) RTSemMutexDestroy(RTSEMMUTEX hMtx)
      */
     AssertReturn(ASMAtomicCmpXchgU32(&pThis->u32Magic, RTSEMMUTEX_MAGIC_DEAD, RTSEMMUTEX_MAGIC), VERR_INVALID_HANDLE);
 
-    IPRT_LINUX_SAVE_EFL_AC();
-
     spin_lock_irqsave(&pThis->Spinlock, fSavedIrq);
     RTListForEach(&pThis->WaiterList, pCur, RTSEMMUTEXLNXWAITER, ListEntry)
     {
@@ -153,8 +144,6 @@ RTDECL(int) RTSemMutexDestroy(RTSEMMUTEX hMtx)
         RTMemFree(pThis);
     }
 
-    IPRT_LINUX_RESTORE_EFL_AC();
-
     return VINF_SUCCESS;
 }
 RT_EXPORT_SYMBOL(RTSemMutexDestroy);
@@ -261,7 +250,6 @@ DECLINLINE(int) rtSemMutexLinuxRequest(RTSEMMUTEX hMutexSem, RTMSINTERVAL cMilli
     struct task_struct *pSelf = current;
     unsigned long       fSavedIrq;
     int                 rc;
-    IPRT_LINUX_SAVE_EFL_AC();
 
     /*
      * Validate.
@@ -301,15 +289,10 @@ DECLINLINE(int) rtSemMutexLinuxRequest(RTSEMMUTEX hMutexSem, RTMSINTERVAL cMilli
      * No, so go to sleep.
      */
     else
-    {
-        rc = rtSemMutexLinuxRequestSleep(pThis, cMillies, fInterruptible, fSavedIrq);
-        IPRT_LINUX_RESTORE_EFL_ONLY_AC();
-        return rc;
-    }
+        return rtSemMutexLinuxRequestSleep(pThis, cMillies, fInterruptible, fSavedIrq);
 
     IPRT_DEBUG_SEMS_STATE_RC(pThis, 'M', rc);
     spin_unlock_irqrestore(&pThis->Spinlock, fSavedIrq);
-    IPRT_LINUX_RESTORE_EFL_ONLY_AC();
     return rc;
 }
 
@@ -348,7 +331,6 @@ RTDECL(int) RTSemMutexRelease(RTSEMMUTEX hMtx)
     struct task_struct *pSelf = current;
     unsigned long       fSavedIrq;
     int                 rc;
-    IPRT_LINUX_SAVE_EFL_AC();
 
     /*
      * Validate.
@@ -384,7 +366,6 @@ RTDECL(int) RTSemMutexRelease(RTSEMMUTEX hMtx)
     spin_unlock_irqrestore(&pThis->Spinlock, fSavedIrq);
 
     AssertRC(rc);
-    IPRT_LINUX_RESTORE_EFL_AC();
     return rc;
 }
 RT_EXPORT_SYMBOL(RTSemMutexRelease);
@@ -395,7 +376,6 @@ RTDECL(bool) RTSemMutexIsOwned(RTSEMMUTEX hMutexSem)
     PRTSEMMUTEXINTERNAL pThis = hMutexSem;
     unsigned long       fSavedIrq;
     bool                fOwned;
-    IPRT_LINUX_SAVE_EFL_AC();
 
     /*
      * Validate.
@@ -411,7 +391,6 @@ RTDECL(bool) RTSemMutexIsOwned(RTSEMMUTEX hMutexSem)
     fOwned = pThis->pOwnerTask != NULL;
     spin_unlock_irqrestore(&pThis->Spinlock, fSavedIrq);
 
-    IPRT_LINUX_RESTORE_EFL_AC();
     return fOwned;
 
 }
