@@ -1,4 +1,4 @@
-/* $Id: thread-r0drv-linux.c 103354 2015-10-13 14:24:51Z bird $ */
+/* $Id: thread-r0drv-linux.c 100317 2015-05-14 15:59:15Z bird $ */
 /** @file
  * IPRT - Threads, Ring-0 Driver, Linux.
  */
@@ -59,11 +59,9 @@ RT_EXPORT_SYMBOL(RTThreadNativeSelf);
 
 static int rtR0ThreadLnxSleepCommon(RTMSINTERVAL cMillies)
 {
-    IPRT_LINUX_SAVE_EFL_AC();
     long cJiffies = msecs_to_jiffies(cMillies);
     set_current_state(TASK_INTERRUPTIBLE);
     cJiffies = schedule_timeout(cJiffies);
-    IPRT_LINUX_RESTORE_EFL_AC();
     if (!cJiffies)
         return VINF_SUCCESS;
     return VERR_INTERRUPTED;
@@ -86,7 +84,6 @@ RT_EXPORT_SYMBOL(RTThreadSleepNoLog);
 
 RTDECL(bool) RTThreadYield(void)
 {
-    IPRT_LINUX_SAVE_EFL_AC();
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 4, 20)
     yield();
 #else
@@ -95,7 +92,6 @@ RTDECL(bool) RTThreadYield(void)
     sys_sched_yield();
     schedule();
 #endif
-    IPRT_LINUX_RESTORE_EFL_AC();
     return true;
 }
 RT_EXPORT_SYMBOL(RTThreadYield);
