@@ -1,10 +1,10 @@
-/* $Id: thread2-r0drv-linux.c 103354 2015-10-13 14:24:51Z bird $ */
+/* $Id: thread2-r0drv-linux.c 100874 2015-06-09 14:01:31Z bird $ */
 /** @file
  * IPRT - Threads (Part 2), Ring-0 Driver, Linux.
  */
 
 /*
- * Copyright (C) 2006-2012 Oracle Corporation
+ * Copyright (C) 2006-2015 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -102,6 +102,13 @@ DECLHIDDEN(int) rtThreadNativeAdopt(PRTTHREADINT pThread)
 }
 
 
+DECLHIDDEN(void) rtThreadNativeWaitKludge(PRTTHREADINT pThread)
+{
+    /** @todo fix RTThreadWait/RTR0Term race on linux. */
+    RTThreadSleep(1); NOREF(pThread);
+}
+
+
 DECLHIDDEN(void) rtThreadNativeDestroy(PRTTHREADINT pThread)
 {
     NOREF(pThread);
@@ -130,20 +137,16 @@ DECLHIDDEN(int) rtThreadNativeCreate(PRTTHREADINT pThreadInt, PRTNATIVETHREAD pN
 {
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 4)
     struct task_struct *NativeThread;
-    IPRT_LINUX_SAVE_EFL_AC();
 
     RT_ASSERT_PREEMPTIBLE();
 
     NativeThread = kthread_run(rtThreadNativeMain, pThreadInt, "iprt-%s", pThreadInt->szName);
 
-    if (!IS_ERR(NativeThread))
-    {
-        *pNativeThread = (RTNATIVETHREAD)NativeThread;
-        IPRT_LINUX_RESTORE_EFL_AC();
-        return VINF_SUCCESS;
-    }
-    IPRT_LINUX_RESTORE_EFL_AC();
-    return VERR_GENERAL_FAILURE;
+    if (IS_ERR(NativeThread))
+        return VERR_GENERAL_FAILURE;
+
+    *pNativeThread = (RTNATIVETHREAD)NativeThread;
+    return VINF_SUCCESS;
 #else
     return VERR_NOT_IMPLEMENTED;
 #endif
